@@ -1,7 +1,7 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 # Perl DateTime extension for converting to/from the French Revolutionary calendar
-# Copyright (c) 2003, 2004, 2010, 2011, 2012, 2014 Jean Forget. All rights reserved.
+# Copyright (c) 2003, 2004, 2010, 2011, 2012, 2014, 2016 Jean Forget. All rights reserved.
 #
 # See the license in the embedded documentation below.
 #
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 use Params::Validate qw(validate SCALAR BOOLEAN OBJECT);
 use Roman;
@@ -661,8 +661,8 @@ sub strftime {
       # And if the user asks for %E!,
       # it defaults to E! because neither %E! nor %! exist.
       $f =~ s/
-	        %([EO]?([*%a-zA-Z]))
-              | %{(\w+)}
+	        \%([EO]?([*%a-zA-Z]))
+              | \%\{(\w+)\}
              /
               $3 ? ($self->can($3) ? $self->$3() : "\%{$3}")
                  : ($formats{$1} ? $formats{$1}->($self)
@@ -1419,10 +1419,10 @@ L<http://en.wikipedia.org/wiki/French_Republican_Calendar>
 
 =head1 LICENSE STUFF
 
-Copyright (c)  2003, 2004, 2010,  2012, 2014 Jean Forget.   All rights
-reserved. This  program is free software. You  can distribute, modify,
-and otherwise mangle DateTime::Calendar::FrenchRevolutionary under the
-same terms as perl 5.16.3.
+Copyright (c)  2003, 2004,  2010, 2012, 2014,  2016 Jean  Forget.  All
+rights reserved.  This program is  free software. You  can distribute,
+modify,  and otherwise  mangle DateTime::Calendar::FrenchRevolutionary
+under the same terms as perl 5.16.3.
 
 This program is  distributed under the same terms  as Perl 5.16.3: GNU
 Public License version 1 or later and Perl Artistic License
