@@ -1,7 +1,7 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 # Perl DateTime extension for providing English strings for the French Revolutionary calendar
-# Copyright (c) 2003, 2004, 2010, 2011, 2014 Jean Forget. All rights reserved.
+# Copyright (c) 2003, 2004, 2010, 2011, 2014, 2016 Jean Forget. All rights reserved.
 #
 # See the license in the embedded documentation below.
 #
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.12'; # same as parent module DT::C::FR
+$VERSION = '0.13'; # same as parent module DT::C::FR
 
 my @months_short  = qw (Vin Fog Fro Sno Rai Win Bud Flo Mea Rea Hea Fru S-C);
 
@@ -545,7 +545,7 @@ French enter Mons.
 16 Brumaire III Army of the North. The fort of Schenk is taken.
 
 0217
-17 Brumaire III Army of the North. The sortie of the Berg-op-zomm
+17 Brumaire III Army of the North. The sortie of the Berg-op-zoom
 garrison is repulsed by a French bayonet charge.
 
 0218
@@ -2236,10 +2236,10 @@ L<http://en.wikipedia.org/wiki/French_Republican_Calendar>
 
 =head1 LICENSE STUFF
 
-Copyright (c)  2003, 2004, 2010,  2012, 2014 Jean Forget.   All rights
-reserved. This  program is free software. You  can distribute, modify,
-and otherwise mangle DateTime::Calendar::FrenchRevolutionary under the
-same terms as perl 5.16.3.
+Copyright (c)  2003, 2004,  2010, 2012, 2014,  2016 Jean  Forget.  All
+rights reserved.  This program is  free software. You  can distribute,
+modify,  and otherwise  mangle DateTime::Calendar::FrenchRevolutionary
+under the same terms as perl 5.16.3.
 
 This program is  distributed under the same terms  as Perl 5.16.3: GNU
 Public License version 1 or later and Perl Artistic License
