@@ -1,7 +1,7 @@
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
 #
 # Perl DateTime extension for providing French strings for the French Revolutionary calendar
-# Copyright (c) 2003, 2004, 2010, 2011, 2014 Jean Forget. All rights reserved.
+# Copyright (c) 2003, 2004, 2010, 2011, 2014, 2016 Jean Forget. All rights reserved.
 #
 # See the license in the embedded documentation below.
 #
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.12'; # same as parent module DT::C::FR
+$VERSION = '0.13'; # same as parent module DT::C::FR
 
 my @months_short  = qw (Vnd Bru Fri Niv Plu Vnt Ger Flo Pra Mes The Fru S-C);
 #my @add_days_short= qw (Vertu Génie Trav Raison Récomp Révol);
@@ -540,7 +540,7 @@ obligé de la repasser après un combat meurtrier.
 
 0217
 17 Brumaire III Armée du Nord. La sortie de la garnison de
-Berg-op-zomm est repoussée.
+Berg-op-zoom est repoussée.
 
 0218
 18 Brumaire I Prise de la ville de Tournay par les Français.
@@ -2314,10 +2314,10 @@ L<http://datetime.perl.org/>
 
 =head1 LICENSE STUFF
 
-Copyright (c)  2003, 2004, 2010,  2012, 2014 Jean Forget.   All rights
-reserved. This  program is free software. You  can distribute, modify,
-and otherwise mangle DateTime::Calendar::FrenchRevolutionary under the
-same terms as perl 5.16.3.
+Copyright (c)  2003, 2004,  2010, 2012, 2014,  2016 Jean  Forget.  All
+rights reserved.  This program is  free software. You  can distribute,
+modify,  and otherwise  mangle DateTime::Calendar::FrenchRevolutionary
+under the same terms as perl 5.16.3.
 
 This program is  distributed under the same terms  as Perl 5.16.3: GNU
 Public License version 1 or later and Perl Artistic License
